# bollhav ⚽ 🌊

Model definition framework that standardizes code at pipe and model level. Follow the link to understand the [abstractions](ABSTRACTIONS.md) used in this library.

- [Model level](MODEL.md)
- [Pipe level](Environment)
- [Postgres](POSTGRES.md)
- [Parquet](PARQUET.md)

Match your models with [tags!](TAGS.md)

## Installation
```bash
pip install bollhav
```

## Testing

Tests use `pytest`. Run the full suite:
```bash
pytest tests/
```
